=========================
mythx_cli.group package
=========================

mythx_cli.group.close
---------------------

.. automodule:: mythx_cli.group.close
    :members:
    :undoc-members:
    :show-inheritance:

    .. autofunction:: group_close


mythx_cli.group.list
--------------------

.. automodule:: mythx_cli.group.list
    :members:
    :undoc-members:
    :show-inheritance:

    .. autofunction:: group_list


mythx_cli.group.open
--------------------

.. automodule:: mythx_cli.group.open
    :members:
    :undoc-members:
    :show-inheritance:

    .. autofunction:: group_open


mythx_cli.group.status
----------------------

.. automodule:: mythx_cli.group.status
    :members:
    :undoc-members:
    :show-inheritance:

    .. autofunction:: group_status
